@@ -18,17 +18,25 @@ qx.Class.define("callbackery.ui.Footer", {
         }));
         var cfg = callbackery.data.Config.getInstance().getBaseConfig();
         var label;
-        var who = '';
+        var who = '', support;
+        if ( cfg.company_support ){
+            support = this.tr('Support') + ': '
+                    + '<a href="mailto:' + cfg.company_support + '" style="color: #444;">' + cfg.company_support + '</a>';
+        }
         if ( cfg.company_name ){
-            who = ', created by ';
+            var company;
             if (cfg.company_url){
-                who += '<a href="' + cfg.company_url + '" style="color: #444;" target="_blank">' + cfg.company_name + '</a>';
+                company = '<a href="' + cfg.company_url + '" style="color: #444;" target="_blank">' + cfg.company_name + '</a>';
             }
             else {
-                who += cfg.company_name;
+                company = cfg.company_name;
             }
+            who += ' ' + this.tr('Implemented by %1', company) + '.';
         }
-        this.add(new qx.ui.basic.Atom(this.tr('release %1, %2%3','#VERSION#','#DATE#',who)).set({
+        if (support) {
+            who += ' ' + support;
+        }
+        this.add(new qx.ui.basic.Atom(this.tr('Version %1, %2%3','#VERSION#','#DATE#',who)).set({
             textColor : '#444',
             rich : true,
             paddingRight  : 5,
