@@ -149,6 +149,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
                 if (s.set.filter){
                     s.set.filter = RegExp(s.filter);
                 }
+                if (s.set.placeholder){
+                    s.set.placeholder = this['tr'](s.set.placeholder);
+                }
                 control.set(s.set);
             }
  
